@@ -18,7 +18,7 @@
 #'	 \item "MATTHEWS2016" (Matthews et al., 2016) for coastlines and plate polygons. 
 #' }
 #' 
-#' If \code{model} is a \code{\link{platemodel}} class object, then the function will try to use the GPLates desktop application (\url{http://www.gplates.org/}) to reconstruct the coordinates (local reconstruction submodule).
+#' If \code{model} is a \code{\link{platemodel}} class object, then the function will try to use the GPLates desktop application (\url{https://www.gplates.org/}) to reconstruct the coordinates (local reconstruction submodule).
 #' Plate models are available in chronosphere with the \code{\link{fetch}} function. See \code{\link{datasets}} for the available models.
 #' The function will try to find the main GPlates executable in its default installation directory. If this does not succeed, use \code{path.gplates} to enter the full path to the GPlates executable as a \code{character} string.
 #' 
@@ -46,21 +46,22 @@
 #' @param listout (\code{logical})If multiple ages are given, the output can be returned as a \code{list} if \code{listout = TRUE}.
 #' @param verbose (\code{logical}) Should call URLs (remote submodule) or console feedback (local-submodule) be printed?
 #' @param cleanup (\code{logical}) Argument of the local reconstruction submodule. Should the temporary files be deleted immediately after reconstructions?
+#' @param plateperiod (\code{logical}) Argument of the local reconstruction submodule. Should the durations of the plates be forced on the partitioned feature? If these are set to \code{TRUE} and the plate duration estimates are long, then you might lose some data.
 #' @param dir (\code{character}) Argument of the local reconstruction submodule. Directory where the temporary files of the reconstruction are stored (defaults to a temporary directory created by R). Remember to toggle \code{cleanup} if you want to see the files.  
 #' @return A \code{numeric} matrix if \code{x} is a \code{numeric}, \code{matrix} or \code{data.frame}, or \code{Spatial*} class objects, depending on input.
 #' @examples
 #' \donttest{
-#' # With the web service
+#' # With the web service (GPlates Web Service was offline at submission)
 #' # simple matrices
-#'	reconstruct(matrix(c(95, 54), nrow=1), 140)
+#' # reconstruct(matrix(c(95, 54), nrow=1), 140)
 #'	
 #'	# points reconstruction
 #'	xy <-cbind(long=c(95,142), lat=c(54, -33))
-#'	reconstruct(xy, 140)
+#'	# reconstruct(xy, 140)
 #'
 #' # coastlines/plates
-#'	coast <- reconstruct("coastlines", 140)
-#'	plate <- reconstruct("plates", 139)
+#' # coast <- reconstruct("coastlines", 140)
+#' # plate <- reconstruct("plates", 139)
 #'	
 #'  }
 #' @rdname reconstruct
@@ -74,7 +75,7 @@ setGeneric("reconstruct", function(x,...) standardGeneric("reconstruct"))
 setMethod(
 	"reconstruct", 
 	signature="matrix", 
-	function(x,age, model="PALEOMAP", listout=TRUE, verbose=FALSE, enumerate=TRUE, chunk=200, reverse=FALSE, path.gplates=NULL, cleanup=TRUE, dir=NULL){
+	function(x,age, model="PALEOMAP", listout=TRUE, verbose=FALSE, enumerate=TRUE, chunk=200, reverse=FALSE, path.gplates=NULL, cleanup=TRUE, dir=NULL,plateperiod=FALSE){
 	 
 		# Check long lat!
 		if(!is.numeric(age)) age <- as.numeric(age)
@@ -104,7 +105,7 @@ setMethod(
                     if(is.character(model)){
 					   fresh <- IteratedPointReconstruction(coords=x, chunk=chunk, age=age[i], model=model, reverse=reverse, verbose=verbose)
                     }else{
-                        fresh <- reconstructGPlates(x=x, age=age[i], model=model, path.gplates=path.gplates, dir=dir, verbose=verbose, cleanup=cleanup)
+                        fresh <- reconstructGPlates(x=x, age=age[i], model=model, path.gplates=path.gplates, dir=dir, verbose=verbose, cleanup=cleanup, plateperiod=plateperiod)
                     }
 					# list
 					if(listout){
@@ -142,7 +143,7 @@ setMethod(
                     if(is.character(model)){
 					   container[index,] <- IteratedPointReconstruction(coords=current, chunk=chunk, age=ageLevs[i], model=model, reverse=reverse, verbose=verbose)
 				    }else{
-                        container[index,] <- reconstructGPlates(x=current, age=ageLevs[i], model=model, path.gplates=path.gplates, dir=dir, verbose=verbose, cleanup=cleanup)
+                        container[index,] <- reconstructGPlates(x=current, age=ageLevs[i], model=model, path.gplates=path.gplates, dir=dir, verbose=verbose, cleanup=cleanup, plateperiod=plateperiod)
                     }
                 }
 			}
@@ -152,7 +153,7 @@ setMethod(
             if(is.character(model)){
                 container <- IteratedPointReconstruction(coords=x, chunk=chunk, age=age, model=model, reverse=reverse, verbose=verbose)
             }else{
-                container <- reconstructGPlates(x=x, age=age, model=model, path.gplates=path.gplates, dir=dir, verbose=verbose, cleanup=cleanup)
+                container <- reconstructGPlates(x=x, age=age, model=model, path.gplates=path.gplates, dir=dir, verbose=verbose, cleanup=cleanup, plateperiod=plateperiod)
             }
 		}
 
@@ -182,7 +183,7 @@ setMethod(
 setMethod(
 	"reconstruct", 
 	signature="character", 
-	function(x,age, model="PALEOMAP", listout=TRUE, verbose=FALSE,path.gplates=NULL, cleanup=TRUE, dir=NULL){
+	function(x,age, model="PALEOMAP", listout=TRUE, verbose=FALSE,path.gplates=NULL, cleanup=TRUE, dir=NULL, plateperiod=FALSE){
         if(!any(x==c("plates", "coastlines"))) stop("Invalid 'x' argument.\nThe only valid character input are \"plates\" and \"coastlines\"")
 		# vectorized
 		if(length(age)>1){
@@ -205,7 +206,7 @@ setMethod(
 					if(is.character(model)){
 						feature <- gplates_reconstruct_static_polygons(age=age[i], model=model, verbose=verbose)
 					}else{
-						feature <- reconstructGPlates(x="plates", age=age[i], model=model, path.gplates=path.gplates, dir=dir, verbose=verbose, cleanup=cleanup)
+						feature <- reconstructGPlates(x="plates", age=age[i], model=model, path.gplates=path.gplates, dir=dir, verbose=verbose, cleanup=cleanup, plateperiod=plateperiod)
 					}
 				}
 
@@ -228,7 +229,7 @@ setMethod(
 				if(is.character(model)){
 					container <- gplates_reconstruct_static_polygons(age=age, model=model, verbose=verbose)
 				}else{
-					container <- reconstructGPlates(x="plates", age=age, model=model, path.gplates=path.gplates, dir=dir, verbose=verbose, cleanup=cleanup)
+					container <- reconstructGPlates(x="plates", age=age, model=model, path.gplates=path.gplates, dir=dir, verbose=verbose, cleanup=cleanup, plateperiod=plateperiod)
 				}
 			}
 		}
@@ -242,7 +243,7 @@ setMethod(
 setMethod(
 	"reconstruct",
 	"SpatialPolygonsDataFrame", 
-	function(x, age, model="PALEOMAP", listout=TRUE, verbose=FALSE,path.gplates=NULL, cleanup=TRUE, dir=NULL){
+	function(x, age, model="PALEOMAP", listout=TRUE, verbose=FALSE,path.gplates=NULL, cleanup=TRUE, dir=NULL, plateperiod=FALSE){
 		if(!is.na(x@proj4string)){
 			x <- sp::spTransform(x, sp::CRS("+proj=longlat"))
 		}else{
@@ -304,7 +305,7 @@ setMethod(
 
 
 
-reconstructGPlates <- function(x, age, model, path.gplates=NULL,dir=NULL, verbose=FALSE, cleanup=TRUE){
+reconstructGPlates <- function(x, age, model, path.gplates=NULL,dir=NULL, verbose=FALSE, cleanup=TRUE, plateperiod=FALSE){
 	if(class(model)!="platemodel") stop("You need a GPlates tectonic model for this method.")
 	if(! requireNamespace("rgdal", quietly=TRUE)) stop("This method requires the 'rgdal' package to run")
 	
@@ -444,6 +445,14 @@ reconstructGPlates <- function(x, age, model, path.gplates=NULL,dir=NULL, verbos
 				pathToFileNoEXT <- gsub(".gpml", "",model@polygons)
 			}
 		}
+
+		# inheritance of appearance and disappearance dates
+		if(plateperiod){
+			pPer <- 1
+		}else{
+			pPer <- 0
+		}
+		
 	# 3. Execute GPlates commands
 		# convert to gpml
 		if(!is.character(x)){
@@ -454,7 +463,7 @@ reconstructGPlates <- function(x, age, model, path.gplates=NULL,dir=NULL, verbos
 		# do the plate assignment
 		if(!is.character(x)){
 			if(verbose) message("Assigning plate IDs to .gpml file.")
-			assignment <- paste(gplatesExecutable, " assign-plate-ids -e 1 -p ", platePolygons, " -l ",pathToFileNoEXT,".gpml", sep="")
+			assignment <- paste(gplatesExecutable, " assign-plate-ids -e ",pPer," -p ", platePolygons, " -l ",pathToFileNoEXT,".gpml", sep="")
 			system(assignment, ignore.stdout=!verbose,ignore.stderr=!verbose)
 		}
 		# do reconstruction
